@@ -8,15 +8,15 @@ package Lemonldap::NG::Portal::AuthApache;
 use strict;
 use Lemonldap::NG::Portal::Simple;
 
-our $VERSION = '0.11';
+our $VERSION = '0.99';
 
-## @method int authInit()
+## @apmethod int authInit()
 # @return Lemonldap::NG::Portal constant
 sub authInit {
     PE_OK;
 }
 
-## @method int extractFormInfo()
+## @apmethod int extractFormInfo()
 # Read username return by Apache authentication system.
 # By default, authentication is valid if REMOTE_USER environment
 # variable is set.
@@ -24,7 +24,8 @@ sub authInit {
 sub extractFormInfo {
     my $self = shift;
     unless ( $self->{user} = $ENV{REMOTE_USER} ) {
-        print STDERR "Apache is not configured to authenticate users !";
+        $self->lmLog( 'Apache is not configured to authenticate users !',
+            'error' );
         return PE_ERROR;
     }
 
@@ -33,18 +34,55 @@ sub extractFormInfo {
     PE_OK;
 }
 
-# @method int authenticate()
+## @apmethod int setAuthSessionInfo()
+# Set _user and authenticationLevel.
+# @return Lemonldap::NG::Portal constant
+sub setAuthSessionInfo {
+    my $self = shift;
+
+    # Store user submitted login for basic rules
+    $self->{sessionInfo}->{'_user'} = $self->{'user'};
+
+    $self->{sessionInfo}->{authenticationLevel} = $self->{apacheAuthnLevel};
+
+    PE_OK;
+}
+
+## @apmethod int authenticate()
 # Does nothing.
 # @return Lemonldap::NG::Portal constant
 sub authenticate {
     PE_OK;
 }
 
+## @apmethod int authFinish()
+# Does nothing.
+# @return Lemonldap::NG::Portal constant
+sub authFinish {
+    PE_OK;
+}
+
+## @apmethod int authLogout()
+# Does nothing
+# @return Lemonldap::NG::Portal constant
+sub authLogout {
+    PE_OK;
+}
+
+## @apmethod boolean authForce()
+# Does nothing
+# @return result
+sub authForce {
+    return 0;
+}
+
 1;
 __END__
 
 =head1 NAME
 
+=encoding utf8
+
 Lemonldap::NG::Portal::Apache - Perl extension for building Lemonldap::NG
 compatible portals with Apache authentication.
 
@@ -66,7 +104,7 @@ compatible portals with Apache authentication.
     print $portal->redirect( -uri => 'https://portal/menu');
   }
   else {
-    # If the user enters here, IT MEANS THAT CAS REDIRECTION DOES NOT WORK
+    # If the user enters here, IT MEANS THAT APACHE AUTHENTICATION DOES NOT WORK
     print $portal->header('text/html; charset=utf8'); # DON'T FORGET THIS (see CGI(3))
     print "<html><body><h1>Unable to work</h1>";
     print "This server isn't well configured. Contact your administrator.";
