@@ -8,6 +8,9 @@
 #-------------------------------------------------------------------------------
 # CHANGELOGS
 #-------------------------------------------------------------------------------
+# 2009-02-09 - Version 0.3.1
+# Author(s) : Thomas CHEMINEAU
+#   - Fixe a bug in libertySignOn function, to retrieve correct $providerID
 # 2008-03-25 - Version 0.3
 # Author(s) : Thomas CHEMINEAU
 #   - Fixe some bugs into logout process from IDP or SP ;
@@ -34,7 +37,7 @@ use UNIVERSAL qw( isa can VERSION );
 *EXPORT_TAGS = *Lemonldap::NG::Portal::SharedConf::EXPORT_TAGS;
 *EXPORT      = *Lemonldap::NG::Portal::SharedConf::EXPORT;
 
-our $VERSION = '0.32';
+our $VERSION = '0.99';
 use base qw(Lemonldap::NG::Portal::SharedConf);
 
 #===============================================================================
@@ -238,17 +241,15 @@ sub process {
     }
     elsif ( $urldir eq $self->PC_LA_URLFT ) {
 
-        $self->{error} = $self->_subProcess(
-            qw( libertyFederationTermination log autoRedirect ));
+        $self->{error} =
+          $self->_subProcess(qw( libertyFederationTermination autoRedirect ));
 
         # federationTerminationReturn
     }
     elsif ( $urldir eq $self->PC_LA_URLFTR ) {
 
         $self->{error} = $self->_subProcess(
-            qw( libertyFederationTerminationReturn log
-              autoRedirect )
-        );
+            qw( libertyFederationTerminationReturn autoRedirect ));
 
         # singleLogout : called when IDP request Logout.
     }
@@ -266,20 +267,19 @@ sub process {
     }
     elsif ( $urldir eq $self->PC_LA_URLSLR ) {
 
-        $self->{error} =
-          $self->_subProcess(qw( libertySingleLogoutReturn log ));
+        $self->{error} = $self->_subProcess(qw( libertySingleLogoutReturn ));
 
         # soapCall
     }
     elsif ( $urldir eq $self->PC_LA_URLSC ) {
 
-        $self->{error} = $self->_subProcess(qw( libertySoapCall log ));
+        $self->{error} = $self->_subProcess(qw( libertySoapCall ));
 
         # soapEndpoint
     }
     elsif ( $urldir eq $self->PC_LA_URLSE ) {
 
-        $self->{error} = $self->_subProcess(qw( libertySoapEndpoint log ));
+        $self->{error} = $self->_subProcess(qw( libertySoapEndpoint ));
 
         # Direct access or simple access -> main
         # WARNING : we permit authentication on service.
@@ -290,9 +290,8 @@ sub process {
     {
 
         $self->{error} = $self->_subProcess(
-            qw( libertyRetrieveExistingSession
-              libertyExtractFormInfo libertySignOn log
-              autoRedirect )
+            qw( libertyRetrieveExistingSession libertyExtractFormInfo
+              libertySignOn autoRedirect )
         );
 
         # Not in liberty authentication process.
@@ -310,8 +309,8 @@ sub process {
     # TODO Warning, PE_OK==0 and process returns 0 if an error occurs!
     # my $err = $self->SUPER::process(@_);
     #return $err unless( $err != PE_OK );
-    # TODO: Why ? log and  autoRedirect are executed with SUPER::process
-    #$err = $self->_subProcess(qw( log autoRedirect ))
+    # TODO: Why ? autoRedirect is executed with SUPER::process
+    #$err = $self->_subProcess(qw( autoRedirect ))
     #  if ( $self->{urldc} );
     #return $err;
     # So I think we have just to write this
@@ -363,6 +362,27 @@ sub store {
     return $self->_assertionSessionStore( $self->{userNameIdentifier} );
 }
 
+## @apmethod int authFinish()
+# Does nothing.
+# @return Lemonldap::NG::Portal constant
+sub authFinish {
+    PE_OK;
+}
+
+## @apmethod int authLogout()
+# Does nothing
+# @return Lemonldap::NG::Portal constant
+sub authLogout {
+    PE_OK;
+}
+
+## @apmethod boolean authForce()
+# Does nothing
+# @return result
+sub authForce {
+    return 0;
+}
+
 #===============================================================================
 #===============================================================================
 
@@ -799,6 +819,9 @@ sub libertySetSessionInfo {
     $self->{user} = $uidValues[0]
       if (@uidValues);
 
+    # authenticationLevel 1 for external authentication
+    $self->{sessionInfo}->{authenticationLevel} = 1;
+
     return PE_OK;
 }
 
@@ -822,7 +845,7 @@ sub libertySignOn {
     # TODO :
     #   Catching error when retrieving $providerID.
 
-    my $providerID = $self->{LAidps}->{ $self->{idp}->{id} }->{url};
+    my $providerID = $self->{laIdps}->{ $self->{idp}->{id} }->{url};
 
     if (
         my $error = $lassoLogin->initAuthnRequest(
@@ -1371,6 +1394,8 @@ __END__
 
 =head1 NAME
 
+=encoding utf8
+
 Lemonldap::NG::Portal::AuthLA - Provide Liberty Alliance Authentication for
 FederID project.
 
