@@ -11,9 +11,9 @@ use Lemonldap::NG::Portal::AuthLDAP;
 
 use base qw(Lemonldap::NG::Portal::AuthLDAP);
 
-our $VERSION = '0.11';
+our $VERSION = '0.99';
 
-## @method int authInit()
+## @apmethod int authInit()
 # Check if SSL environment variables are set.
 # @return Lemonldap::NG::Portal constant
 sub authInit {
@@ -28,7 +28,7 @@ sub authInit {
 # Directory.
 # So authenticate is overloaded to return only PE_OK.
 
-## @method int extractFormInfo()
+## @apmethod int extractFormInfo()
 # Read username in SSL environment variables.
 # If $ENV{$self->{SSLVar}} is not set and SSLRequire is not set to 1, call
 # Lemonldap::NG::Portal::AuthLDAP::extractFormInfo()
@@ -38,38 +38,77 @@ sub extractFormInfo {
     my $self = shift;
     my $user = $self->https ? $ENV{ $self->{SSLVar} } : 0;
     if ($user) {
-        $self->{sessionInfo}->{authenticationLevel} = 5;
         $self->{user} = $user;
-        $self->{authFilter} =
+        $self->{AuthLDAPFilter} ||=
           '(&(' . $self->{SSLLDAPField} . "=$user)(objectClass=inetOrgPerson))";
         return PE_OK;
     }
     elsif ( $self->{SSLRequire} ) {
+        $self->_sub( 'userError',
+            "No certificate found for $ENV{REMOTE_ADDR}" );
         return PE_CERTIFICATEREQUIRED;
     }
-    $self->{authFilter} = '';
+    $self->{AuthLDAPFilter} = '';
     return $self->SUPER::extractFormInfo(@_);
 }
 
-## @method int authenticate()
+## @apmethod int setAuthSessionInfo()
+# Set _user and authenticationLevel.
+# @return Lemonldap::NG::Portal constant
+sub setAuthSessionInfo {
+    my $self = shift;
+
+    # Store user certificate login for basic rules
+    $self->{sessionInfo}->{'_user'} = $self->{'user'};
+
+    $self->{sessionInfo}->{authenticationLevel} = $self->{SSLAuthnLevel};
+    PE_OK;
+}
+
+## @apmethod int authenticate()
 # Call Lemonldap::NG::Portal::AuthLDAP::authenticate() if user was not
 # authenticated by SSL.
 # @return Lemonldap::NG::Portal constant
 sub authenticate {
     my $self = shift;
     if (    $self->{sessionInfo}->{authenticationLevel}
-        and $self->{sessionInfo}->{authenticationLevel} > 4 )
+        and $self->{sessionInfo}->{authenticationLevel} >=
+        $self->{SSLAuthnLevel} )
     {
         return PE_OK;
     }
     return $self->SUPER::authenticate(@_);
 }
 
+## @apmethod int authFinish()
+# Does nothing.
+# @return Lemonldap::NG::Portal constant
+sub authFinish {
+    PE_OK;
+}
+
+## @apmethod int authLogout()
+# Does nothing
+# @return Lemonldap::NG::Portal constant
+sub authLogout {
+    PE_OK;
+}
+
+## @apmethod boolean authForce()
+# Does nothing
+# @return result
+sub authForce {
+    return 0;
+}
+
 1;
+
 __END__
 
 =head1 NAME
 
+=encoding utf8
+
 Lemonldap::NG::Portal::AuthSSL - Perl extension for building Lemonldap::NG
 compatible portals with SSL authentication.
 
