@@ -1,14 +1,14 @@
-##@file
-# Cross domain extension for Lemonldap::NG portals.
+## @file
+# Deprecated: use "cda" parameter instead
 
-##@class
-# Cross domain extension for Lemonldap::NG portals.
+## @class
+# Deprecated: use "cda" parameter instead
 package Lemonldap::NG::Portal::CDA;
 
 use strict;
 use Lemonldap::NG::Portal::SharedConf qw(:all);
 
-our $VERSION = '0.04';
+our $VERSION = '0.99';
 use base ('Lemonldap::NG::Portal::SharedConf');
 
 *EXPORT_OK   = *Lemonldap::NG::Portal::SharedConf::EXPORT_OK;
@@ -19,31 +19,15 @@ use base ('Lemonldap::NG::Portal::SharedConf');
 # OVERLOADED SUB #
 ##################
 
-## @method int existingSession()
-# Existing sessions must not be reauthenticated in CDA usage
-# @return Lemonldap::NG::Portal error code
-sub existingSession {
-    PE_DONE;
-}
-
-## @method int autoRedirect()
-# Same as Lemonldap::NG::Portal::SharedConf::autoRedirect(), but add ID in URL
-# if the user was redirected to the portal from another domain.
-# @return Lemonldap::NG::Portal error code
-sub autoRedirect {
-    my $self       = shift;
-    my $tmp        = $self->{domain};
-    my $cookieName = $self->{cookieName};
-
-    if (    $self->{urldc}
-        and $self->{urldc} !~ m#^https?://[^/]*$tmp/#oi
-        and $self->{id}
-        and $self->{urldc} !~ m#[\?&]?$cookieName=\w+&?#oi )
-    {
-        $self->{urldc} .= ( $self->{urldc} =~ /\?{1}/oi ) ? '&' : '?';
-        $self->{urldc} .= $cookieName . "=" . $self->{id};
-    }
-    return $self->SUPER::autoRedirect(@_);
+## @cmethod Lemonldap::NG::Portal::CDA new(array params)
+# Call Lemonldap::NG::Portal::SharedConf::new() with "cda" parameter set to 1
+# @param params Lemonldap::NG::Portal::SharedConf::new() parameters
+# @return New Lemonldap::NG::Portal::CDA object
+sub new {
+    my $class = shift;
+    my $self  = $class->SUPER::new(@_);
+    $self->{cda} = 1;
+    return $self;
 }
 
 1;
@@ -51,6 +35,8 @@ __END__
 
 =head1 NAME
 
+=encoding utf8
+
 Lemonldap::NG::Portal::CDA - Perl extension for building Lemonldap::NG
 compatible portals with Cross Domain Authentication.
 
@@ -58,6 +44,7 @@ compatible portals with Cross Domain Authentication.
 
   use Lemonldap::NG::Portal::SharedConf;
   my $portal = new Lemonldap::NG::Portal::SharedConf( {
+         cda => 1,
          configStorage => {
              type        => 'DBI',
              dbiChain    => "dbi:mysql:...",
@@ -101,11 +88,8 @@ Modify your httpd.conf:
 
 =head1 DESCRIPTION
 
-This library just overload few methods of L<Lemonldap::NG::Portal::SharedConf>
-to add Cross Domain Authentication. Handlers that are not used in the same
-domain than the portal must inherit from L<Lemonldap::NG::Handler::CDA>.
-
-See L<Lemonldap::NG::Portal::SharedConf> for usage and other methods.
+This file is maintened only for compatibility. Now set "cda => 1" in the
+portal.
 
 =head1 SEE ALSO
 
