@@ -8,7 +8,7 @@ package Lemonldap::NG::Portal::_WebForm;
 use Lemonldap::NG::Portal::Simple qw(:all);
 use strict;
 
-our $VERSION = '0.2';
+our $VERSION = '0.99';
 
 ## @apmethod int authInit()
 # Does nothing.
@@ -23,27 +23,18 @@ sub authInit {
 sub extractFormInfo {
     my $self = shift;
     return PE_FIRSTACCESS
-      unless ( $self->param('user') || $self->param('mail') );
+      unless ( $self->param('user') );
     return PE_FORMEMPTY
       unless (
-        (
-            (
-                length( $self->{'user'} = $self->param('user') ) > 0
-            )
-            && (
-                (
-                    length( $self->{'password'} = $self->param('password') ) > 0
-                )
-                || (
-                    length($self->{'newpassword'} = $self->param('newpassword') ) > 0
-                )
-            )
-        )
-        || ( length( $self->{'mail'} = $self->param('mail') ) > 0 )
+        ( $self->{user} = $self->param('user') )
+        && (   ( $self->{password} = $self->param('password') )
+            || ( $self->{newpassword} = $self->param('newpassword') ) )
       );
-    $self->{'oldpassword'}     = $self->param('oldpassword');
-    $self->{'confirmpassword'} = $self->param('confirmpassword');
-    $self->{'timezone'} = $self->param('timezone');
+    $self->{oldpassword}     = $self->param('oldpassword');
+    $self->{confirmpassword} = $self->param('confirmpassword');
+    $self->{timezone}        = $self->param('timezone');
+    $self->{userControl} ||= '^[\w\.\-@]+$';
+    return PE_MALFORMEDUSER unless ( $self->{user} =~ /$self->{userControl}/o );
     PE_OK;
 }
 
@@ -53,8 +44,14 @@ sub extractFormInfo {
 sub setAuthSessionInfo {
     my $self = shift;
 
-    # Level 2 for web form based authentication
-    $self->{sessionInfo}->{authenticationLevel} = 2;
+    # authenticationLevel
+    # -1 if password can be remebered
+    # +1 for user/password with HTTPS
+    $self->{_authnLevel} ||= 0;
+    $self->{_authnLevel} += 1 if $self->https();
+    $self->{_authnLevel} -= 1 if $self->{portalAutocomplete};
+
+    $self->{sessionInfo}->{authenticationLevel} = $self->{_authnLevel};
 
     # Store user submitted login for basic rules
     $self->{sessionInfo}->{'_user'} = $self->{'user'};
@@ -68,7 +65,7 @@ sub setAuthSessionInfo {
 
     # Store user timezone
     $self->{sessionInfo}->{'_timezone'} = $self->{'timezone'};
-    
+
     PE_OK;
 }
 
